@@ -21,9 +21,10 @@ import logging as _logging
 import sys as _sys
 
 
-__version__ = '3.0'
-__url__ = 'http://rss2email.infogami.com'
+__version__ = '3.1'
+__url__ = 'https://github.com/wking/rss2email'
 __author__ = 'W. Trevor King'
+__email__ = 'rss2email@tremily.us'
 __copyright__ = '(C) 2004 Aaron Swartz. GNU GPL 2 or 3.'
 __contributors__ = [
     'Aaron Swartz (original author)',
